@@ -3,14 +3,14 @@ import string, json, os
 class languagestring(object):
 	def __init__(self):
 		self.string = string
-
-		with open(f'{os.path.realpath(__file__)}/languagestring/assets/language_detailed.json','r') as f:
+		cp ='/'.join( f'{os.path.realpath(__file__)}'.split('/')[:-2])
+		with open(f'{cp}/languagestring/assets/language_detailed.json','r') as f:
 			self.language_dict = json.load(f)
 			f.close()
 
 
 	def language_string(self,language):
-		return ''.join(ls.language_dict[language]['lowercase']['letter'])
+		return ''.join(self.language_dict[language]['lowercase']['letter'])
 
 
 
